#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import argparse
import os
import sys
from pathlib import Path

from funcs import check, step, run

# Путь к пакетам wine
PATH_WINE_RPM = Path('./etersoft-repo/')
# Путь к лицензии wine
PATH_WINE_LIC = Path('./wine-etersoft.lic')


# Текущий пользователь
CURRENT_USER = os.getlogin()
# Путь текущего пользователя
PATH_USER_HOME = Path(os.path.expanduser('~{}'.format(CURRENT_USER)))
PATH_WINE_PREFIX = PATH_USER_HOME.joinpath('.wine')

ap = argparse.ArgumentParser()

ap.add_argument(
    '-v', '--version', help='Версия утилиты.',
    action='store_true', required=False, default=False,
)
ap.add_argument(
    '--verbose', help='Вывод отладочной информации.',
    action='store_true', required=False, default=False,
)
args = ap.parse_args()

if args.version:
    print('PlanWizard install v0.1')
    sys.exit(0)


command = 'sudo sh ./etersoft-repo/wine-etersoft-install.sh'
step(
    'Устанавливаем wine',
    run, {'command': command, 'silent': False}
)

command = 'WINEPREFIX=$HOME/.wine winecfg'
step(
    'Настраиваем wine',
    run, {'command': command}
)

command = 'cp -f wine-etersoft.lic $HOME/.wine/drive_c/windows/system32'
step(
    'Копируем лицензию wine',
    run, {'command': command, 'silent': not args.verbose}
)

command = 'WINEPREFIX=$HOME/.wine wine ../Installer/MFC90/vcredist_x86.exe && wine ../Installer/VCRedist_2013/vcredist_x86.exe && wine ../Installer/VCRedist_2015-2019/VC_redist.x86.exe'
step(
    'Устанавливаем библиотеки MFC90, VCRedist2013, VCRedist2015-2019',
    run, {'command': command, 'silent': False}
)

command = 'WINEPREFIX=$HOME/.wine wine ../setup.exe'.format(CURRENT_USER)
step(
    'Устанавливаем GPSmeta',
    run, {'command': command, 'silent': not args.verbose}
)

step(
    'Корректируем права',
    run, {'command': 'chown -R {} {}'.format(CURRENT_USER, PATH_WINE_PREFIX), 'silent': not args.verbose}
)

print('Установка успешно завершена.')
